Installation
============

You can install e2xgrader from source or via PyPi:

Install via PyPi
----------------

.. code-block:: sh

   pip install e2xgrader


Install from source
-------------------

.. code-block:: sh

   pip install --no-cache-dir git+https://github.com/DigiKlausur/e2xgrader.git


After installation make sure to :ref:`activate a mode <e2xgrader_modes>` activate a mode and :ref:`configure <configure_e2xgrader>` `nbgrader` to work with `e2xgrader`.